==> moodle-1.4.3-pgsql.tgz: moodle/lang/fr/editor.php <==
<?php // $Id$ 

$string['about'] = ' propos de cet diteur';
$string['absbottom'] = 'Absbottom';
$string['address'] = 'Adresse';
$string['alignment'] = 'Alignement';
$string['alternatetext'] = 'Texte alt';
$string['anchorname'] = 'Nom d\'ancrage';
$string['anchors'] = 'Ancrages';
$string['anchorhelp'] = 'Ceci ne fait que crer un ancrage. Vous devrez encore crer le lien manuellement.';
$string['baseline'] = 'Ligne de base';
$string['bold'] = 'Gras';
$string['borderthickness'] = 'paisseur bordure';
$string['bottom'] = 'Bas';
$string['browse'] = 'Choisir';
$string['cancel'] = 'Annuler';
$string['cellpadding'] = 'Rempl. cellule';
$string['cellspacing'] = 'Espace cellule';
$string['choosechar'] = 'Choisir un caractre';
$string['chooseicon'] = 'Choisir une icne  insrer';
$string['close'] = 'Fermer';
$string['cols'] = 'Colonnes';
$string['copy'] = 'Copier la slection';
$string['createanchor'] = 'Crer un ancrage';
$string['createfolder'] = 'Nouveau dossier';
$string['createlink'] = 'Insrer un lien web';
$string['cut'] = 'Couper la slection';
$string['delete'] = 'Supprimer';
$string['filebrowser'] = 'Slection des fichiers';
$string['forecolor'] = 'Couleur du texte';
$string['fullscreen'] = 'diteur plein cran';
$string['heading'] = 'Titre';
$string['height'] = 'Hauteur';
$string['hilitecolor'] = 'Couleur d\'arrire-plan';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Filet horizontal';
$string['htmlmode'] = 'Mode code HTML';
$string['imageurl'] = 'URL de l\'image';
$string['indent'] = 'Augmenter le niveau d\'indentation';
$string['insertchar'] = 'Insrer un caractre spcial';
$string['insertimage'] = 'Insrer une image';
$string['insertlink'] = 'Insrer un lien';
$string['insertsmile'] = 'Insrer une binette';
$string['inserttable'] = 'Insrer un tableau';
$string['italic'] = 'Italique';
$string['justifycenter'] = 'Centr';
$string['justifyfull'] = 'Justifi';
$string['justifyleft'] = 'Align  gauche';
$string['justifyright'] = 'Align  droite';
$string['layout'] = 'Mise en page';
$string['left'] = 'Gauche';
$string['lefttoright'] = 'Direction de gauche  droite';
$string['linkproperties'] = 'Proprits du lien';
$string['linktarget'] = 'Cible';
$string['linktargetblank'] = 'Nouvelle fentre';
$string['linktargetnone'] = 'Aucune';
$string['linktargetother'] = 'Autre (en panne)';
$string['linktargetself'] = 'Mme cadre (frame)';
$string['linktargettop'] = 'Mme fentre';
$string['linktitle'] = 'Titre';
$string['linkurl'] = 'URL';
// $string['middle'] = 'Milieu';
$string['middle'] = 'middle';
$string['minimize'] = 'Minimiser l\'diteur';
$string['move'] = 'Dplacer';
$string['normal'] = 'Normal';
$string['notimage'] = 'Le fichier slectionn n\'est pas une image. Veuillez slectionner une image !';
$string['notset'] = 'Par dfaut';
$string['ok'] = 'OK';
$string['orderedlist'] = 'Liste numrote';
$string['outdent'] = 'Diminuer le niveau d\'indentation';
$string['paste'] = 'Coller depuis le presse-papier';
$string['path'] = 'Chemin';
$string['percent'] = 'Pour-cent';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Passer l\'diteur en mode fentre';
$string['preformatted'] = 'Prformatt';
$string['preview'] = 'Prvisualiser';
$string['properties'] = 'Proprits';
$string['redo'] = 'Rtablir la dernire action';
$string['removelink'] = 'Supprimer le lien';	
$string['rename'] = 'Renommer';
$string['right'] = 'Droite';
$string['righttoleft'] = 'Direction de droite  gauche';
$string['rows'] = 'Ranges';
$string['selectcolor'] = 'Choisir une couleur';
$string['selection'] = 'Slection';
$string['showhelp'] = 'Aide sur l\'diteur';
$string['size'] = 'Taille';
$string['spacing'] = 'Espacement';
$string['strikethrough'] = 'Barr';
$string['subscript'] = 'Indice';
$string['superscript'] = 'Exposant';
$string['textindicator'] = 'Style courant';
$string['textmode'] = 'Vous tes en MODE TEXTE. Cliquez sur le bouton [<>] pour retourner en MODE WYSIWYG.';
$string['texttop'] = 'Dbut du texte';
$string['top'] = 'Haut';
$string['type'] = 'Type';
$string['underline'] = 'Soulign';
$string['undo'] = 'Annuler la dernire action';
$string['unorderedlist'] = 'Liste non numrote';
$string['upload'] = 'Dposer';
$string['vertical'] = 'Vertical';
$string['width'] = 'Largeur';
$string['wordclean'] = 'Nettoyer le code HTML de Word';
$string['zip'] = 'Compresser';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/fr/editor.php <==
<?php // $Id$ 

$string['about'] = ' propos de cet diteur';
$string['absbottom'] = 'Bas (absolu)';
$string['address'] = 'Adresse';
$string['alertnoselectedtext'] = 'Veuillez d\'abord slectionner du texte!';
$string['alignment'] = 'Alignement';
$string['alternatetext'] = 'Texte alt';
$string['anchorhelp'] = 'Ceci ne fait que crer un ancrage. Vous devrez encore crer le lien manuellement.';
$string['anchorname'] = 'Nom d\'ancrage';
$string['anchors'] = 'Ancrages';
$string['baseline'] = 'Ligne de base';
$string['bold'] = 'Gras';
$string['borderthickness'] = 'paisseur bordure';
$string['bottom'] = 'Bas';
$string['browse'] = 'Choisir';
$string['cancel'] = 'Annuler';
$string['cellpadding'] = 'Rempl. cellule';
$string['cellspacing'] = 'Espace cellule';
$string['choosechar'] = 'Choisir un caractre';
$string['chooseicon'] = 'Choisir une icne  insrer';
$string['close'] = 'Fermer';
$string['closeafterreplace'] = 'Fermer aprs remplacement';
$string['cols'] = 'Colonnes';
$string['copy'] = 'Copier la slection';
$string['createanchor'] = 'Crer un ancrage';
$string['createfolder'] = 'Nouveau dossier';
$string['createlink'] = 'Insrer un lien web';
$string['cut'] = 'Couper la slection';
$string['cutpastemozilla'] = 'Il est malheureusement impossible d\'utiliser les raccourcis clavier (ou mme le bouton Coller) pour coller du texte dans l\diteur WYSIWYG, en raison d\'une fonction de scurit incluse dans certaines versions des navigateurs Mozilla et Firefox.<br /><br />Vous pouvez contourner ce problme de trois faons&nbsp;:<br /> (1) au lieu d\'utiliser Ctrl-v ou Cmd-v, utiliser Maj-Insrer&nbsp;;<br /> (2) utiliser le menu dition -> Coller de votre navigateur&nbsp;;<br /> (3) changer les prfrences de votre navigateur en modifiant votre fichier user.js.<br /><br />Pour plus d\'aide  ce sujet, cliquer le bouton OK ci-dessous, ou Annuler pour retourner  l\'diteur';
$string['delete'] = 'Supprimer';
$string['filebrowser'] = 'Slection des fichiers';
$string['findwhat'] = 'Rechercher';
$string['fontname'] = 'Nom de police';
$string['fontsize'] = 'Corps de police';
$string['forecolor'] = 'Couleur du texte';
$string['formatblock'] = 'Format';
$string['fullscreen'] = 'diteur plein cran';
$string['heading'] = 'Titre';
$string['height'] = 'Hauteur';
$string['hilitecolor'] = 'Couleur d\'arrire-plan';
$string['horizontal'] = 'Horizontal';
$string['horizontalrule'] = 'Filet horizontal';
$string['htmlmode'] = 'Mode code HTML';
$string['imageurl'] = 'URL de l\'image';
$string['indent'] = 'Augmenter le niveau d\'indentation';
$string['insertchar'] = 'Insrer un caractre spcial';
$string['insertimage'] = 'Insrer une image';
$string['insertlink'] = 'Insrer un lien';
$string['insertsmile'] = 'Insrer une binette';
$string['inserttable'] = 'Insrer un tableau';
$string['italic'] = 'Italique';
$string['itemsreplaced'] = 'lments remplacs';
$string['justifycenter'] = 'Centr';
$string['justifyfull'] = 'Justifi';
$string['justifyleft'] = 'Align  gauche';
$string['justifyright'] = 'Align  droite';
$string['layout'] = 'Mise en page';
$string['left'] = 'Gauche';
$string['lefttoright'] = 'Direction de gauche  droite';
$string['linkproperties'] = 'Proprits du lien';
$string['linktarget'] = 'Cible';
$string['linktargetblank'] = 'Nouvelle fentre';
$string['linktargetnone'] = 'Aucune';
$string['linktargetother'] = 'Autre (en panne)';
$string['linktargetself'] = 'Mme cadre (frame)';
$string['linktargettop'] = 'Mme fentre';
$string['linktitle'] = 'Titre';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Distinction de la casse';
$string['middle'] = 'Milieu';
$string['minimize'] = 'Minimiser l\'diteur';
$string['move'] = 'Dplacer';
$string['nolink'] = 'Pas de lien automatique';
$string['normal'] = 'Normal';
$string['notimage'] = 'Le fichier slectionn n\'est pas une image. Veuillez slectionner une image !';
$string['notset'] = 'Par dfaut';
$string['ok'] = 'OK';
$string['options'] = 'Options';
$string['orderedlist'] = 'Liste numrote';
$string['outdent'] = 'Diminuer le niveau d\'indentation';
$string['paste'] = 'Coller depuis le presse-papier';
$string['path'] = 'Chemin';
$string['percent'] = 'Pour-cent';
$string['pixels'] = 'Pixels';
$string['popupeditor'] = 'Passer l\'diteur en mode fentre';
$string['preformatted'] = 'Prformatt';
$string['preview'] = 'Prvisualiser';
$string['properties'] = 'Proprits';
$string['redo'] = 'Refaire la dernire action';
$string['regularexpressions'] = 'Utiliser les expressions rgulires (GREP)';
$string['removelink'] = 'Supprimer le lien';	
$string['rename'] = 'Renommer';
$string['replaceall'] = 'Tout remplacer';
$string['replacewith'] = 'Remplacer';
$string['right'] = 'Droite';
$string['righttoleft'] = 'Direction de droite  gauche';
$string['rows'] = 'Ranges';
$string['searchandreplace'] = 'Rechercher et remplacer';
$string['searchnotfound'] = 'Chane non trouve';
$string['selectcolor'] = 'Choisir une couleur';
$string['selection'] = 'Slection';
$string['showhelp'] = 'Aide sur l\'diteur';
$string['size'] = 'Taille';
$string['spacing'] = 'Espacement';
$string['strikethrough'] = 'Barr';
$string['subscript'] = 'Indice';
$string['superscript'] = 'Exposant';
$string['textindicator'] = 'Style actuel';
$string['textmode'] = 'Vous tes en MODE TEXTE. Cliquez sur le bouton [<>] pour retourner en MODE WYSIWYG.';
$string['texttop'] = 'Dbut du texte';
$string['top'] = 'Haut';
$string['type'] = 'Type';
$string['underline'] = 'Soulign';
$string['undo'] = 'Annuler la dernire action';
$string['unorderedlist'] = 'Liste non numrote';
$string['upload'] = 'Dposer';
$string['vertical'] = 'Vertical';
$string['width'] = 'Largeur';
$string['wordclean'] = 'Nettoyer le code HTML de Word';
$string['zip'] = 'Compresser';

?>
